% Design incoherent frames using a distance barrier.
% Bisection is used to find the best coherence value.

m = 90;
n = 100;         % frame size
K = 2000;        % number of iterations
run_also_ISPM = 0; % run also ISPM with the same frame size

%-------------------------------------------
% IDB parameters
lambda = 0.2;    % trade-off factor
gamma0 = 0.1;    % initial step size
rho = 0.999;     % step size decrease factor
search_it = 5;   % number of halving steps in gradient search
tol_stop = 1e-4; % stopping tolerance
K_bis = 15;      % number of bisection iterations
%-------------------------------------------

mu_min = getBound(m,n); % lower coherence bound
Fr = normc(randn(m,n));
mu_max = max(max(abs(Fr'*Fr - eye(n)))); % coherence of a random frame
fprintf("Interval [%f,%f]\n", mu_min, mu_max);
[F_IDB, coh_best, iter_total_count] = bisection_idb(mu_min, mu_max, K_bis, m, n, K, lambda,...
                                      gamma0, rho, search_it, tol_stop);
fprintf("Total number of IDB iterations: %d\n", iter_total_count)
coh_IDB = max(max(abs(F_IDB'*F_IDB - eye(n))));
fprintf("Final IDB coherence: %f\n", coh_IDB)

%-------------------------------------------
% ISPM parameters
alpha = 0.5;
%-------------------------------------------
if run_also_ISPM
    [F_ISPM, coh_best, iter_total_count] = bisection_ispm(mu_min, mu_max, K_bis, m, n, K, alpha, tol_stop);
    fprintf("Total number of ISPM iterations: %d\n", iter_total_count)
    coh_ISPM = max(max(abs(F_ISPM'*F_ISPM - eye(n))));
    fprintf("Final ISPM coherence: %f\n", coh_ISPM)
end